@@ -3,13 +3,14 @@ BEGIN {
   $App::DuckPAN::DDG::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: DDG related functionality of duckpan
-$App::DuckPAN::DDG::VERSION = '0.152';
+$App::DuckPAN::DDG::VERSION = '0.153';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
 use Module::Pluggable::Object;
 use Class::Load ':all';
 use Data::Printer;
+use List::Util qw (first);
 
 sub get_dukgo_user_pass {
     my ( $self ) = @_;
@@ -31,9 +32,7 @@ sub print_failed_modules {
     if(%failed_to_load) {
         print "\nThese instant answers were not loaded:\n";
         p(%failed_to_load);
-
-        print "To learn more about installing Perl dependencies, please read https://duck.co/duckduckhack/faq#how-do-i-install-a-missing-perl-dependency.\n";
-        print "Note: You can ignore these errors if you're not working on these instant answers.\n";
+        print "To learn more about installing Perl dependencies, please read https://duck.co/duckduckhack/faq#how-do-i-install-a-missing-perl-dependency.\nNote: You can ignore these errors if you're not working on these instant answers.\n" if first { /dependencies/ } values %failed_to_load;
     }
 }
 
@@ -142,7 +141,7 @@ App::DuckPAN::DDG - DDG related functionality of duckpan
 
 =head1 VERSION
 
-version 0.152
+version 0.153
 
 =head1 AUTHOR
 
