@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Perl::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Perl related functionality for duckpan
-$App::DuckPAN::Perl::VERSION = '0.152';
+$App::DuckPAN::Perl::VERSION = '0.153';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
@@ -14,6 +14,7 @@ use Config::INI::Reader;
 use Config::INI::Writer;
 use Data::Dumper;
 use LWP::Simple;
+use List::Util qw/ first /;
 use File::Temp qw/ :POSIX /;
 use version;
 use Parse::CPAN::Packages::Fast;
@@ -76,6 +77,12 @@ sub cpanminus_install_error {
 sub duckpan_install {
 	my ( $self, @modules ) = @_;
 	my $mirror = $self->app->duckpan;
+	my $force_install;
+	if ($modules[0] eq 'force') {
+		# We sent in a signal to force installation
+		$force_install = 1;
+		shift @modules;
+	}
 	my $modules_string = join(' ',@modules);
 	my $tempfile = tmpnam;
 	if (is_success(getstore($self->app->duckpan_packages,$tempfile))) {
@@ -86,7 +93,7 @@ sub duckpan_install {
 			my $module = $packages->package($_);
 			if ($module) {
 				local $@;
-				
+
 				# see if we have an env variable for this module
 				my $sp = $_;
 				$sp =~ s/\:\:/_/g;
@@ -97,18 +104,22 @@ sub duckpan_install {
 				my $duckpan_module_version = version->parse($module->version);
 				my $duckpan_module_url = $self->app->duckpan.'authors/id/'.$module->distribution->pathname;
 
-				if ($pin_version && $localver) {
+				my $install_it;
+				if ($force_install) {
+					$install_it = 1;
+				} elsif ($pin_version && $localver) {
 					print "$_: $localver installed, $pin_version pin, $duckpan_module_version latest\n";
 					if ($pin_version > $localver && $duckpan_module_version > $localver && $duckpan_module_version <= $pin_version) {
-						push @to_install, $duckpan_module_url unless grep { $_ eq $duckpan_module_url } @to_install;
+						$install_it = 1;
 					}
 				} elsif ($localver && $localver == $duckpan_module_version) {
 					$self->app->print_text("You already have latest version of ".$_." with ".$localver."\n");
 				} elsif ($localver && $localver > $duckpan_module_version) {
 					$self->app->print_text("You have a newer version of ".$_." with ".$localver." (duckpan has ".$duckpan_module_version.")\n");
 				} else {
-					push @to_install, $duckpan_module_url unless grep { $_ eq $duckpan_module_url } @to_install;
+					$install_it = 1;
 				}
+				push @to_install, $duckpan_module_url if ($install_it && !(first { $_ eq $duckpan_module_url } @to_install));
 			} else {
 				$self->app->print_text("[ERROR] Can't find package ".$_." on ".$self->app->duckpan."\n");
 				$error = 1;
@@ -116,6 +127,7 @@ sub duckpan_install {
 		}
 		return 1 if $error;
 		return 0 unless @to_install;
+		unshift @to_install,'-f'  if ($force_install); # cpanm will do the actual forcing.
 		return system("cpanm ".join(" ",@to_install));
 	} else {
 		$self->app->print_text("[ERROR] Can't reach duckpan at ".$self->app->duckpan."!\n");
@@ -147,7 +159,7 @@ App::DuckPAN::Perl - Perl related functionality for duckpan
 
 =head1 VERSION
 
-version 0.152
+version 0.153
 
 =head1 AUTHOR
 
